# aplib
A pure Python module for decompressing aPLib compressed data

Adapted from the original C source code from http://ibsensoftware.com/files/aPLib-1.1.1.zip  
Approximately 20 times faster than other Python implementations.  
Compatible with both Python 2 and 3.  
